@@ -26,6 +26,7 @@
 # ------------------------------------------------------------------------------
 
 from django.db.models import Case, Value, When, IntegerField, BooleanField
+from django.conf import settings
 
 from eoxserver.core.config import get_eoxserver_config
 from eoxserver.core.decoders import config, enum
@@ -58,12 +59,20 @@ class NoSuchPrefix(NoSuchLayer):
     locator = 'layer'
 
 
+DEFAULT_EOXS_LAYER_SUFFIX_SEPARATOR = '__'
+
+
 class LayerMapper(object):
     """ Default layer mapper.
     """
 
-    def __init__(self, supported_layer_types, suffix_separator):
+    def __init__(self, supported_layer_types, suffix_separator=None):
         self.supported_layer_types = supported_layer_types
+        if suffix_separator is None:
+            suffix_separator = getattr(
+                settings, 'EOXS_LAYER_SUFFIX_SEPARATOR',
+                DEFAULT_EOXS_LAYER_SUFFIX_SEPARATOR
+            )
         self.suffix_separator = suffix_separator
 
     def get_layer_description(self, eo_object, raster_styles, geometry_styles):
@@ -173,7 +182,7 @@ class LayerMapper(object):
 
     def lookup_layer(self, layer_name, suffix, style, filters_expressions,
                      sort_by, time, ranges, bands, wavelengths, elevation,
-                     zoom):
+                     zoom, variables):
         """ Lookup the layer from the registered objects.
         """
         reader = LayerMapperConfigReader(get_eoxserver_config())
@@ -268,7 +277,7 @@ class LayerMapper(object):
                         ).first()
                         if browse_type:
                             browse = _generate_browse_from_browse_type(
-                                product, browse_type
+                                product, browse_type, variables
                             )
                             if browse:
                                 browses.append(browse)
@@ -397,7 +406,7 @@ class LayerMapper(object):
                             masked_browses.append(
                                 MaskedBrowse(
                                     browse=_generate_browse_from_browse_type(
-                                        product, browse_type
+                                        product, browse_type, variables
                                     ),
                                     mask=Mask.from_model(mask, mask_type)
                                 )
@@ -430,7 +439,7 @@ class LayerMapper(object):
                         # browse type
                         else:
                             browse = _generate_browse_from_browse_type(
-                                product, browse_type
+                                product, browse_type, variables
                             )
                             if browse:
                                 browses.append(browse)
@@ -599,7 +608,7 @@ class LayerMapperConfigReader(config.Reader):
     color = config.Option(type=str, default='grey')
 
 
-def _generate_browse_from_browse_type(product, browse_type):
+def _generate_browse_from_browse_type(product, browse_type, variables):
     if not browse_type.red_or_grey_expression:
         return None
 
@@ -656,6 +665,7 @@ def _generate_browse_from_browse_type(product, browse_type):
             nodata_values,
             fields_and_coverages,
             product,
+            variables,
         )
     return None
 
